use mongodb::{ Client, Database };

pub mod schemas;

pub async fn get_client() -> Database {
    match Client::with_uri_str(match std::env::var("MONGODB_URI") {
        Err(e) => {
            std::process::exit({
                eprintln!("Error: {:?}", e);
                1
            })
        },
        Ok(val) => val
    }).await {
        Ok(client) => client.database("schoollabs-test"),
        Err(e) => {
            std::process::exit({
                eprintln!("Error: {:?}", e);
                1
            })
        }
    }
}

#[cfg(test)]
mod tests {
    use super::*;
    use tokio_test;
    use serde::{Deserialize, Serialize};


    async fn check_mongo_works_fn() {
        #[derive(Debug, Serialize, Deserialize)]
        struct Book {
            title: String,
            author: String
        }
    
        let db = get_client().await;
    
        let books = db.collection::<Book>("books");
    
        let book = vec![Book { title: "1984".to_string(), author: "George Orwell".to_string() }];
    
        match books.insert_many(book, None).await {
            Ok(_) => assert_eq!(1, 1),
            Err(_) => assert_eq!(1, 0)
        };
    }
    
    #[test]
    fn check_mongo_works() {
        tokio_test::block_on(check_mongo_works_fn())
    }
}